@@ -5,14 +5,15 @@ r"""Contains calculations related to turbulence and time series perturbations.""
 
 import numpy as np
 
+from .tools import make_take
 from ..package_tools import Exporter
-from ..xarray import preprocess_xarray
+from ..xarray import preprocess_and_wrap
 
 exporter = Exporter(globals())
 
 
 @exporter.export
-@preprocess_xarray
+@preprocess_and_wrap(wrap_like='ts')
 def get_perturbation(ts, axis=-1):
     r"""Compute the perturbation from the mean of a time series.
 
@@ -40,14 +41,12 @@ def get_perturbation(ts, axis=-1):
     .. math:: x(t)^{\prime} = x(t) - \overline{x(t)}
 
     """
-    slices = [slice(None)] * ts.ndim
-    slices[axis] = None
-    mean = ts.mean(axis=axis)[tuple(slices)]
+    mean = ts.mean(axis=axis)[make_take(ts.ndim, axis)(None)]
     return ts - mean
 
 
 @exporter.export
-@preprocess_xarray
+@preprocess_and_wrap(wrap_like='u')
 def tke(u, v, w, perturbation=False, axis=-1):
     r"""Compute turbulence kinetic energy.
 
@@ -105,15 +104,15 @@ def tke(u, v, w, perturbation=False, axis=-1):
         v = get_perturbation(v, axis=axis)
         w = get_perturbation(w, axis=axis)
 
-    u_cont = np.mean(u * u, axis=axis)
-    v_cont = np.mean(v * v, axis=axis)
-    w_cont = np.mean(w * w, axis=axis)
+    u_cont = np.mean(u**2, axis=axis)
+    v_cont = np.mean(v**2, axis=axis)
+    w_cont = np.mean(w**2, axis=axis)
 
     return 0.5 * np.sqrt(u_cont + v_cont + w_cont)
 
 
 @exporter.export
-@preprocess_xarray
+@preprocess_and_wrap(wrap_like='vel')
 def kinematic_flux(vel, b, perturbation=False, axis=-1):
     r"""Compute the kinematic flux from two time series.
 
@@ -182,7 +181,7 @@ def kinematic_flux(vel, b, perturbation=False, axis=-1):
 
 
 @exporter.export
-@preprocess_xarray
+@preprocess_and_wrap(wrap_like='u')
 def friction_velocity(u, w, v=None, perturbation=False, axis=-1):
     r"""Compute the friction velocity from the time series of velocity components.
 
@@ -240,10 +239,10 @@ def friction_velocity(u, w, v=None, perturbation=False, axis=-1):
 
     """
     uw = kinematic_flux(u, w, perturbation=perturbation, axis=axis)
-    kf = uw * uw
+    kf = uw**2
     if v is not None:
         vw = kinematic_flux(v, w, perturbation=perturbation, axis=axis)
-        kf += vw * vw
+        kf += vw**2
     # the friction velocity is the 4th root of the kinematic momentum flux
     # As an optimization, first do inplace square root, then return the
     # square root of that. This is faster than np.power(..., 0.25)
