@@ -46,6 +46,50 @@ def test_declarative_image():
     return pc.figure
 
 
+@needs_cartopy
+def test_declarative_three_dims_error():
+    """Test making an image plot with three dimensions."""
+    data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
+
+    img = ImagePlot()
+    img.data = data
+    img.field = 'Temperature'
+    img.colormap = 'coolwarm'
+
+    panel = MapPanel()
+    panel.plots = [img]
+
+    pc = PanelContainer()
+    pc.panel = panel
+
+    with pytest.raises(ValueError, match='subset for plotting'):
+        pc.draw()
+
+
+@needs_cartopy
+def test_declarative_four_dims_error():
+    """Test making a contour plot with four dimensions."""
+    data = xr.open_dataset(get_test_data('CAM_test.nc', as_file_obj=False))
+
+    contour = ContourPlot()
+    contour.data = data
+    contour.field = 'PN'
+    contour.linecolor = 'black'
+    contour.contours = list(range(0, 1200, 4))
+
+    panel = MapPanel()
+    panel.plots = [contour]
+    panel.layout = (1, 1, 1)
+    panel.layers = ['coastline', 'borders', 'states', 'land']
+    panel.plots = [contour]
+
+    pc = PanelContainer()
+    pc.panels = [panel]
+
+    with pytest.raises(ValueError, match='subset for plotting'):
+        pc.draw()
+
+
 @pytest.mark.mpl_image_compare(remove_text=True, tolerance=0)
 @needs_cartopy
 def test_declarative_contour():
@@ -343,7 +387,7 @@ def test_declarative_events():
     panel = MapPanel()
     panel.area = 'us'
     panel.projection = 'lcc'
-    panel.layers = ['coastline', 'borders', 'states']
+    panel.layers = []
     panel.plots = [contour, img]
 
     pc = PanelContainer()
@@ -452,7 +496,7 @@ def test_projection_object(ccrs, cfeature):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.02)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0)
 def test_colorfill(cfeature):
     """Test that we can use ContourFillPlot."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -466,7 +510,7 @@ def test_colorfill(cfeature):
 
     panel = MapPanel()
     panel.area = (-110, -60, 25, 55)
-    panel.layers = [cfeature.STATES]
+    panel.layers = []
     panel.plots = [contour]
 
     pc = PanelContainer()
@@ -477,7 +521,7 @@ def test_colorfill(cfeature):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.03)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.)
 def test_colorfill_horiz_colorbar(cfeature):
     """Test that we can use ContourFillPlot."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -491,7 +535,7 @@ def test_colorfill_horiz_colorbar(cfeature):
 
     panel = MapPanel()
     panel.area = (-110, -60, 25, 55)
-    panel.layers = [cfeature.STATES]
+    panel.layers = []
     panel.plots = [contour]
 
     pc = PanelContainer()
@@ -502,7 +546,7 @@ def test_colorfill_horiz_colorbar(cfeature):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.016)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.005)
 def test_colorfill_no_colorbar(cfeature):
     """Test that we can use ContourFillPlot."""
     data = xr.open_dataset(get_test_data('narr_example.nc', as_file_obj=False))
@@ -1003,7 +1047,7 @@ def test_declarative_sfc_obs(ccrs):
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.022)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.)
 @needs_cartopy
 def test_declarative_sfc_text():
     """Test making a surface observation plot with text."""
@@ -1024,7 +1068,7 @@ def test_declarative_sfc_text():
     panel.layout = (1, 1, 1)
     panel.projection = 'lcc'
     panel.area = 'in'
-    panel.layers = ['states']
+    panel.layers = []
     panel.plots = [obs]
 
     # Bringing it all together
@@ -1180,7 +1224,7 @@ def test_declarative_upa_obs():
     return pc.figure
 
 
-@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.11)
+@pytest.mark.mpl_image_compare(remove_text=True, tolerance=0.114)
 @needs_cartopy
 def test_declarative_upa_obs_convert_barb_units():
     """Test making a full upperair observation plot."""
@@ -1208,7 +1252,7 @@ def test_declarative_upa_obs_convert_barb_units():
     panel.layout = (1, 1, 1)
     panel.area = (-124, -72, 20, 53)
     panel.projection = 'lcc'
-    panel.layers = ['coastline', 'borders', 'states', 'land']
+    panel.layers = []
     panel.plots = [obs]
 
     # Bringing it all together
